@@ -13,8 +13,8 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 6514 $
-## |  Last changed: $Date: 2022-08-22 14:31:53 +0200 (Mo, 22 Aug 2022) $
+## |  File version: $Revision: 7620 $
+## |  Last changed: $Date: 2024-02-09 12:57:37 +0100 (Fr, 09 Feb 2024) $
 ## |  Last changed by: $Author: pahlke $
 ## |
 
@@ -27,8 +27,17 @@
 #' @description
 #' Class for conditional power calculations
 #'
+#' @template field_nPlanned
+#' @template field_allocationRatioPlanned
+#' @template field_iterations
+#' @template field_seed
+#' @template field_simulated
+#' @template field_conditionalPower
+#' @template field_thetaH1
+#' @template field_assumedStDev
+#'
 #' @details
-#' This object cannot be created directly; use \code{\link{getConditionalPower}}
+#' This object cannot be created directly; use \code{\link[=getConditionalPower]{getConditionalPower()}}
 #' with suitable arguments to create the results of a group sequential or a combination test design.
 #'
 #' @keywords internal
@@ -53,8 +62,6 @@ ConditionalPowerResults <- setRefClass("ConditionalPowerResults",
             callSuper(...)
 
             .plotSettings <<- PlotSettings()
-            .parameterNames <<- C_PARAMETER_NAMES
-            .parameterFormatFunctions <<- C_PARAMETER_FORMAT_FUNCTIONS
 
             if (!is.null(.stageResults) && is.null(.design)) {
                 .design <<- .stageResults$.design
@@ -113,6 +120,32 @@ ConditionalPowerResults <- setRefClass("ConditionalPowerResults",
     )
 )
 
+#'
+#' @name ConditionalPowerResultsMeans
+#'
+#' @title
+#' Conditional Power Results Means
+#'
+#' @description
+#' Class for conditional power calculations of means data
+#'
+#' @template field_nPlanned
+#' @template field_allocationRatioPlanned
+#' @template field_iterations
+#' @template field_seed
+#' @template field_simulated
+#' @template field_conditionalPower
+#' @template field_thetaH1
+#' @template field_assumedStDev
+#'
+#' @details
+#' This object cannot be created directly; use \code{\link{getConditionalPower}}
+#' with suitable arguments to create the results of a group sequential or a combination test design.
+#'
+#' @keywords internal
+#'
+#' @importFrom methods new
+#'
 ConditionalPowerResultsMeans <- setRefClass("ConditionalPowerResultsMeans",
     contains = "ConditionalPowerResults",
     fields = list(
@@ -219,6 +252,32 @@ ConditionalPowerResultsMultiArmMeans <- setRefClass("ConditionalPowerResultsMult
     )
 )
 
+#'
+#' @name ConditionalPowerResultsRates
+#'
+#' @title
+#' Conditional Power Results Rates
+#'
+#' @description
+#' Class for conditional power calculations of rates data
+#'
+#' @template field_nPlanned
+#' @template field_allocationRatioPlanned
+#' @template field_iterations
+#' @template field_seed
+#' @template field_simulated
+#' @template field_conditionalPower
+#' @template field_pi1
+#' @template field_pi2
+#'
+#' @details
+#' This object cannot be created directly; use \code{\link{getConditionalPower}}
+#' with suitable arguments to create the results of a group sequential or a combination test design.
+#'
+#' @keywords internal
+#'
+#' @importFrom methods new
+#'
 ConditionalPowerResultsRates <- setRefClass("ConditionalPowerResultsRates",
     contains = "ConditionalPowerResults",
     fields = list(
@@ -271,6 +330,31 @@ ConditionalPowerResultsMultiArmRates <- setRefClass("ConditionalPowerResultsMult
     )
 )
 
+#'
+#' @name ConditionalPowerResultsSurvival
+#'
+#' @title
+#' Conditional Power Results Survival
+#'
+#' @description
+#' Class for conditional power calculations of survival data
+#'
+#' @template field_nPlanned
+#' @template field_allocationRatioPlanned
+#' @template field_iterations
+#' @template field_seed
+#' @template field_simulated
+#' @template field_conditionalPower
+#' @template field_thetaH1_survival
+#'
+#' @details
+#' This object cannot be created directly; use \code{\link{getConditionalPower}}
+#' with suitable arguments to create the results of a group sequential or a combination test design.
+#'
+#' @keywords internal
+#'
+#' @importFrom methods new
+#'
 ConditionalPowerResultsSurvival <- setRefClass("ConditionalPowerResultsSurvival",
     contains = "ConditionalPowerResults",
     fields = list(
@@ -315,11 +399,62 @@ ConditionalPowerResultsMultiArmSurvival <- setRefClass("ConditionalPowerResultsM
     )
 )
 
+#'
+#' @name ConditionalPowerResultsEnrichmentMeans
+#'
+#' @title
+#' Conditional Power Results Enrichment Means
+#'
+#' @description
+#' Class for conditional power calculations of enrichment means data
+#'
+#' @template field_nPlanned
+#' @template field_allocationRatioPlanned
+#' @template field_iterations
+#' @template field_seed
+#' @template field_simulated
+#' @template field_conditionalPower
+#' @template field_thetaH1
+#' @template field_assumedStDevs
+#'
+#' @details
+#' This object cannot be created directly; use \code{\link{getConditionalPower}}
+#' with suitable arguments to create the results of a group sequential or a combination test design.
+#'
+#' @keywords internal
+#'
+#' @importFrom methods new
+#'
 ConditionalPowerResultsEnrichmentMeans <- setRefClass("ConditionalPowerResultsEnrichmentMeans",
     contains = "ConditionalPowerResultsMultiArmMeans"
 )
 
-
+#'
+#' @name ConditionalPowerResultsEnrichmentRates
+#'
+#' @title
+#' Conditional Power Results Enrichment Rates
+#'
+#' @description
+#' Class for conditional power calculations of enrichment rates data
+#'
+#' @template field_nPlanned
+#' @template field_allocationRatioPlanned
+#' @template field_iterations
+#' @template field_seed
+#' @template field_simulated
+#' @template field_conditionalPower
+#' @template field_piTreatments
+#' @template field_piControls
+#'
+#' @details
+#' This object cannot be created directly; use \code{\link{getConditionalPower}}
+#' with suitable arguments to create the results of a group sequential or a combination test design.
+#'
+#' @keywords internal
+#'
+#' @importFrom methods new
+#'
 ConditionalPowerResultsEnrichmentRates <- setRefClass("ConditionalPowerResultsEnrichmentRates",
     contains = "ConditionalPowerResultsMultiHypotheses",
     fields = list(
@@ -357,6 +492,16 @@ ConditionalPowerResultsEnrichmentSurvival <- setRefClass("ConditionalPowerResult
 #' @description
 #' Class for multi-arm analysis results based on a closed combination test.
 #'
+#' @template field_intersectionTest
+#' @template field_indices
+#' @template field_adjustedStageWisePValues
+#' @template field_overallAdjustedTestStatistics
+#' @template field_separatePValues
+#' @template field_conditionalErrorRate
+#' @template field_secondStagePValues
+#' @template field_rejected
+#' @template field_rejectedIntersections
+#'
 #' @details
 #' This object cannot be created directly; use \code{\link{getAnalysisResults}}
 #' with suitable arguments to create the multi-arm analysis results of a closed combination test design.
@@ -386,8 +531,6 @@ ClosedCombinationTestResults <- setRefClass("ClosedCombinationTestResults",
             callSuper(...)
 
             .plotSettings <<- PlotSettings()
-            .parameterNames <<- C_PARAMETER_NAMES
-            .parameterFormatFunctions <<- C_PARAMETER_FORMAT_FUNCTIONS
 
             .setParameterType("intersectionTest", C_PARAM_USER_DEFINED)
 
@@ -413,10 +556,6 @@ ClosedCombinationTestResults <- setRefClass("ClosedCombinationTestResults",
             for (param in parametersGenerated) {
                 .setParameterType(param, C_PARAM_GENERATED)
             }
-
-            if (!is.null(.design) && inherits(.design, C_CLASS_NAME_TRIAL_DESIGN_FISHER)) {
-                .parameterFormatFunctions$overallAdjustedTestStatistics <<- ".formatTestStatisticsFisher"
-            }
         },
         show = function(showType = 1, digits = NA_integer_) {
             .show(showType = showType, digits = digits, consoleOutputEnabled = TRUE)
@@ -526,8 +665,13 @@ ClosedCombinationTestResults <- setRefClass("ClosedCombinationTestResults",
 #' \code{AnalysisResults} is the basic class for
 #' \itemize{
 #'   \item \code{\link{AnalysisResultsFisher}},
-#'   \item \code{\link{AnalysisResultsGroupSequential}}, and
-#'   \item \code{\link{AnalysisResultsInverseNormal}}.
+#'   \item \code{\link{AnalysisResultsGroupSequential}},
+#'   \item \code{\link{AnalysisResultsInverseNormal}},
+#'   \item \code{\link{AnalysisResultsMultiArmFisher}},
+#'   \item \code{\link{AnalysisResultsMultiArmInverseNormal}},
+#'   \item \code{\link{AnalysisResultsConditionalDunnett}},
+#'   \item \code{\link{AnalysisResultsEnrichmentFisher}},
+#'   \item \code{\link{AnalysisResultsEnrichmentInverseNormal}}.
 #' }
 #'
 #' @include class_core_parameter_set.R
@@ -560,14 +704,10 @@ AnalysisResults <- setRefClass("AnalysisResults",
     methods = list(
         initialize = function(design, dataInput, ...) {
             callSuper(.design = design, .dataInput = dataInput, ...)
-
             .plotSettings <<- PlotSettings()
-            .parameterNames <<- .getParameterNames(design = design, analysisResults = .self)
-            .parameterFormatFunctions <<- C_PARAMETER_FORMAT_FUNCTIONS
         },
         .setStageResults = function(stageResults) {
             .stageResults <<- stageResults
-            .parameterNames <<- .getParameterNames(design = .design, stageResults = stageResults, analysisResults = .self)
         },
         getPlotSettings = function() {
             return(.plotSettings)
@@ -685,12 +825,13 @@ AnalysisResults <- setRefClass("AnalysisResults",
                     c("assumedStDevs", "thetaH1", "pi1", "pi2", "piTreatments", "piTreatments", "piControl", "piControls"))]
 
                 if (grepl("(MultiArm|Dunnett|Enrichment)", .getClassName(.self))) {
-                    
                     if (all(c("conditionalPowerSimulated", "conditionalRejectionProbabilities") %in% generatedParams)) {
-                        generatedParams <- .moveValue(generatedParams, 
-                            "conditionalPowerSimulated", "conditionalRejectionProbabilities")
+                        generatedParams <- .moveValue(
+                            generatedParams,
+                            "conditionalPowerSimulated", "conditionalRejectionProbabilities"
+                        )
                     }
-                    
+
                     .showParametersOfOneGroup(generatedParams, "Further analysis results",
                         orderByParameterName = FALSE, consoleOutputEnabled = consoleOutputEnabled
                     )
@@ -704,11 +845,12 @@ AnalysisResults <- setRefClass("AnalysisResults",
 
                 if (grepl("(MultiArm|Dunnett)", .getClassName(.self))) {
                     .cat("Legend:\n", heading = 2, consoleOutputEnabled = consoleOutputEnabled)
-                    .cat(paste0(
-                        "  (i): results of treatment arm i vs. control group ",
-                        .dataInput$getNumberOfGroups(), "\n"
-                    ),
-                    consoleOutputEnabled = consoleOutputEnabled
+                    .cat(
+                        paste0(
+                            "  (i): results of treatment arm i vs. control group ",
+                            .dataInput$getNumberOfGroups(), "\n"
+                        ),
+                        consoleOutputEnabled = consoleOutputEnabled
                     )
                 } else if (.isEnrichmentAnalysisResults(.self)) {
                     .cat("Legend:\n", heading = 2, consoleOutputEnabled = consoleOutputEnabled)
@@ -978,7 +1120,8 @@ summary.AnalysisResults <- function(object, ..., type = 1, digits = NA_integer_)
 #' @description
 #' Returns the \code{\link{AnalysisResults}} object as data frame.
 #'
-#' @param x An \code{\link{AnalysisResults}} object created by \code{\link{getAnalysisResults}}.
+#' @param x An \code{\link{AnalysisResults}} object created by \code{\link[=getAnalysisResults]{getAnalysisResults()}}.
+#' @inheritParams param_niceColumnNamesEnabled
 #' @inheritParams param_three_dots
 #'
 #' @details
@@ -990,9 +1133,8 @@ summary.AnalysisResults <- function(object, ..., type = 1, digits = NA_integer_)
 #'
 #' @keywords internal
 #'
-as.data.frame.AnalysisResults <- function(x, row.names = NULL, optional = FALSE, ..., 
+as.data.frame.AnalysisResults <- function(x, row.names = NULL, optional = FALSE, ...,
         niceColumnNamesEnabled = FALSE) {
-        
     parametersToShow <- .getDesignParametersToShow(x)
     if (inherits(x, "AnalysisResultsMultiArm")) {
         parametersToShow <- c(parametersToShow, ".closedTestResults$rejected")
@@ -1006,9 +1148,8 @@ as.data.frame.AnalysisResults <- function(x, row.names = NULL, optional = FALSE,
         "finalStage", "allocationRatioPlanned", "thetaH0", "thetaH1", "pi1", "pi2"
     ))]
     return(.getAsDataFrame(
-        parameterSet = x, 
+        parameterSet = x,
         parameterNames = parametersToShow,
-        tableColumnNames = .getTableColumnNames(design = x$.design),
         niceColumnNamesEnabled = niceColumnNamesEnabled
     ))
 }
@@ -1020,7 +1161,7 @@ as.data.frame.AnalysisResults <- function(x, row.names = NULL, optional = FALSE,
 #' @description
 #' Function to get the names of an \code{\link{AnalysisResults}} object.
 #'
-#' @param x An \code{\link{AnalysisResults}} object created by \code{\link{getAnalysisResults}}.
+#' @param x An \code{\link{AnalysisResults}} object created by \code{\link[=getAnalysisResults]{getAnalysisResults()}}.
 #'
 #' @details
 #' Returns the names of an analysis results that can be accessed by the user.
@@ -1049,6 +1190,30 @@ names.AnalysisResults <- function(x) {
 #' @description
 #' Class for analysis results results based on a group sequential design.
 #'
+#' @template field_normalApproximation
+#' @template field_directionUpper
+#' @template field_thetaH0
+#' @template field_pi1
+#' @template field_pi2
+#' @template field_nPlanned
+#' @template field_allocationRatioPlanned
+#' @template field_thetaH1
+#' @template field_assumedStDev
+#' @template field_equalVariances
+#' @template field_testActions
+#' @template field_conditionalRejectionProbabilities
+#' @template field_conditionalPower
+#' @template field_repeatedConfidenceIntervalLowerBounds
+#' @template field_repeatedConfidenceIntervalUpperBounds
+#' @template field_repeatedPValues
+#' @template field_finalStage
+#' @template field_finalPValues
+#' @template field_finalConfidenceIntervalLowerBounds
+#' @template field_finalConfidenceIntervalUpperBounds
+#' @template field_medianUnbiasedEstimates
+#' @template field_maxInformation
+#' @template field_informationEpsilon
+#'
 #' @details
 #' This object cannot be created directly; use \code{\link{getAnalysisResults}}
 #' with suitable arguments to create the analysis results of a group sequential design.
@@ -1087,6 +1252,28 @@ AnalysisResultsGroupSequential <- setRefClass("AnalysisResultsGroupSequential",
 #' @description
 #' Class for analysis results results based on an inverse normal design.
 #'
+#' @template field_normalApproximation
+#' @template field_directionUpper
+#' @template field_thetaH0
+#' @template field_pi1
+#' @template field_pi2
+#' @template field_nPlanned
+#' @template field_allocationRatioPlanned
+#' @template field_thetaH1
+#' @template field_assumedStDev
+#' @template field_equalVariances
+#' @template field_testActions
+#' @template field_conditionalRejectionProbabilities
+#' @template field_conditionalPower
+#' @template field_repeatedConfidenceIntervalLowerBounds
+#' @template field_repeatedConfidenceIntervalUpperBounds
+#' @template field_repeatedPValues
+#' @template field_finalStage
+#' @template field_finalPValues
+#' @template field_finalConfidenceIntervalLowerBounds
+#' @template field_finalConfidenceIntervalUpperBounds
+#' @template field_medianUnbiasedEstimates
+#'
 #' @details
 #' This object cannot be created directly; use \code{\link{getAnalysisResults}}
 #' with suitable arguments to create the analysis results of a inverse normal design.
@@ -1114,6 +1301,25 @@ AnalysisResultsInverseNormal <- setRefClass("AnalysisResultsInverseNormal",
 #' @description
 #' Class for multi-arm analysis results based on a inverse normal design.
 #'
+#' @template field_normalApproximation
+#' @template field_directionUpper
+#' @template field_thetaH0
+#' @template field_pi1
+#' @template field_pi2
+#' @template field_nPlanned
+#' @template field_allocationRatioPlanned
+#' @template field_thetaH1
+#' @template field_assumedStDevs
+#' @template field_piTreatments
+#' @template field_intersectionTest
+#' @template field_varianceOption
+#' @template field_conditionalRejectionProbabilities
+#' @template field_conditionalPower
+#' @template field_repeatedConfidenceIntervalLowerBounds
+#' @template field_repeatedConfidenceIntervalUpperBounds
+#' @template field_repeatedPValues
+#' @template field_piControl
+#'
 #' @details
 #' This object cannot be created directly; use \code{\link{getAnalysisResults}}
 #' with suitable arguments to create the multi-arm analysis results of an inverse normal design.
@@ -1141,6 +1347,26 @@ AnalysisResultsMultiArmInverseNormal <- setRefClass("AnalysisResultsMultiArmInve
 #' @description
 #' Class for enrichment analysis results based on a inverse normal design.
 #'
+#' @template field_normalApproximation
+#' @template field_directionUpper
+#' @template field_thetaH0
+#' @template field_pi1
+#' @template field_pi2
+#' @template field_nPlanned
+#' @template field_allocationRatioPlanned
+#' @template field_thetaH1
+#' @template field_assumedStDevs
+#' @template field_piTreatments
+#' @template field_intersectionTest
+#' @template field_varianceOption
+#' @template field_conditionalRejectionProbabilities
+#' @template field_conditionalPower
+#' @template field_repeatedConfidenceIntervalLowerBounds
+#' @template field_repeatedConfidenceIntervalUpperBounds
+#' @template field_repeatedPValues
+#' @template field_piControls
+#' @template field_stratifiedAnalysis
+#'
 #' @details
 #' This object cannot be created directly; use \code{\link{getAnalysisResults}}
 #' with suitable arguments to create the enrichment analysis results of an inverse normal design.
@@ -1171,6 +1397,31 @@ AnalysisResultsEnrichmentInverseNormal <- setRefClass("AnalysisResultsEnrichment
 #' @description
 #' Class for analysis results based on a Fisher combination test design.
 #'
+#' @template field_normalApproximation
+#' @template field_directionUpper
+#' @template field_thetaH0
+#' @template field_pi1
+#' @template field_pi2
+#' @template field_nPlanned
+#' @template field_allocationRatioPlanned
+#' @template field_thetaH1
+#' @template field_assumedStDev
+#' @template field_equalVariances
+#' @template field_testActions
+#' @template field_conditionalRejectionProbabilities
+#' @template field_conditionalPower
+#' @template field_repeatedConfidenceIntervalLowerBounds
+#' @template field_repeatedConfidenceIntervalUpperBounds
+#' @template field_repeatedPValues
+#' @template field_finalStage
+#' @template field_finalPValues
+#' @template field_finalConfidenceIntervalLowerBounds
+#' @template field_finalConfidenceIntervalUpperBounds
+#' @template field_medianUnbiasedEstimates
+#' @template field_conditionalPowerSimulated
+#' @template field_iterations
+#' @template field_seed
+#'
 #' @details
 #' This object cannot be created directly; use \code{\link{getAnalysisResults}}
 #' with suitable arguments to create the analysis results of a Fisher combination test design.
@@ -1200,8 +1451,6 @@ AnalysisResultsFisher <- setRefClass("AnalysisResultsFisher",
     )
 )
 
-#'
-#' @name AnalysisResultsMultiArmFisher
 #'
 #' @title
 #' Analysis Results Multi-Arm Fisher
@@ -1209,6 +1458,28 @@ AnalysisResultsFisher <- setRefClass("AnalysisResultsFisher",
 #' @description
 #' Class for multi-arm analysis results based on a Fisher combination test design.
 #'
+#' @template field_normalApproximation
+#' @template field_directionUpper
+#' @template field_thetaH0
+#' @template field_pi1
+#' @template field_pi2
+#' @template field_nPlanned
+#' @template field_allocationRatioPlanned
+#' @template field_thetaH1
+#' @template field_assumedStDevs
+#' @template field_piTreatments
+#' @template field_intersectionTest
+#' @template field_varianceOption
+#' @template field_conditionalRejectionProbabilities
+#' @template field_conditionalPower
+#' @template field_repeatedConfidenceIntervalLowerBounds
+#' @template field_repeatedConfidenceIntervalUpperBounds
+#' @template field_repeatedPValues
+#' @template field_piControl
+#' @template field_conditionalPowerSimulated
+#' @template field_iterations
+#' @template field_seed
+#'
 #' @details
 #' This object cannot be created directly; use \code{\link{getAnalysisResults}}
 #' with suitable arguments to create the multi-arm analysis results of a Fisher combination test design.
@@ -1233,13 +1504,35 @@ AnalysisResultsMultiArmFisher <- setRefClass("AnalysisResultsMultiArmFisher",
 )
 
 #'
-#' @name AnalysisResultsMultiArmFisher
+#' @name AnalysisResultsEnrichmentFisher
 #'
 #' @title
-#' Analysis Results Multi-Arm Fisher
+#' Analysis Results Enrichment Fisher
 #'
 #' @description
-#' Class for multi-arm analysis results based on a Fisher combination test design.
+#' Class for enrichment analysis results based on a Fisher combination test design.
+#'
+#' @template field_normalApproximation
+#' @template field_directionUpper
+#' @template field_thetaH0
+#' @template field_pi1
+#' @template field_pi2
+#' @template field_nPlanned
+#' @template field_thetaH1
+#' @template field_assumedStDevs
+#' @template field_piTreatments
+#' @template field_intersectionTest
+#' @template field_varianceOption
+#' @template field_conditionalRejectionProbabilities
+#' @template field_repeatedConfidenceIntervalLowerBounds
+#' @template field_repeatedConfidenceIntervalUpperBounds
+#' @template field_repeatedPValues
+#' @template field_piControls
+#' @template field_conditionalPowerSimulated
+#' @template field_iterations
+#' @template field_seed
+#' @template field_stratifiedAnalysis
+#'
 #'
 #' @details
 #' This object cannot be created directly; use \code{\link{getAnalysisResults}}
@@ -1274,6 +1567,25 @@ AnalysisResultsEnrichmentFisher <- setRefClass("AnalysisResultsEnrichmentFisher"
 #' @description
 #' Class for multi-arm analysis results based on a conditional Dunnett test design.
 #'
+#' @template field_normalApproximation
+#' @template field_directionUpper
+#' @template field_thetaH0
+#' @template field_pi1
+#' @template field_pi2
+#' @template field_nPlanned
+#' @template field_allocationRatioPlanned
+#' @template field_thetaH1
+#' @template field_assumedStDevs
+#' @template field_piTreatments
+#' @template field_intersectionTest
+#' @template field_varianceOption
+#' @template field_conditionalRejectionProbabilities
+#' @template field_conditionalPower
+#' @template field_repeatedConfidenceIntervalLowerBounds
+#' @template field_repeatedConfidenceIntervalUpperBounds
+#' @template field_repeatedPValues
+#' @template field_piControl
+#'
 #' @details
 #' This object cannot be created directly; use \code{\link{getAnalysisResults}}
 #' with suitable arguments to create the multi-arm analysis results of a conditional Dunnett test design.
@@ -1389,7 +1701,7 @@ AnalysisResultsConditionalDunnett <- setRefClass("AnalysisResultsConditionalDunn
 #' @description
 #' Plots the conditional power together with the likelihood function.
 #'
-#' @param x The analysis results at given stage, obtained from \code{\link{getAnalysisResults}}.
+#' @param x The analysis results at given stage, obtained from \code{\link[=getAnalysisResults]{getAnalysisResults()}}.
 #' @param y Not available for this kind of plot (is only defined to be compatible to the generic plot function).
 #' @inheritParams param_nPlanned
 #' @inheritParams param_stage
@@ -1411,7 +1723,7 @@ AnalysisResultsConditionalDunnett <- setRefClass("AnalysisResultsConditionalDunn
 #'       can be specified (default is \code{1}).
 #' \item \code{piTreatmentRange}: A range of assumed rates pi1 to calculate the conditional power.
 #'       Additionally, if a two-sample comparison was selected, \code{pi2} can be specified (default is the value from
-#'       \code{getAnalysisResults}).
+#'       \code{\link[=getAnalysisResults]{getAnalysisResults()}}).
 #' \item \code{directionUpper}: Specifies the direction of the alternative,
 #'       only applicable for one-sided testing; default is \code{TRUE}
 #'       which means that larger values of the test statistics yield smaller p-values.
@@ -1606,6 +1918,10 @@ plot.AnalysisResults <- function(x, y, ..., type = 1L,
             if (is.null(assumedStDevs)) {
                 assumedStDevs <- as.numeric(x$assumedStDevs)
             }
+
+            gMax <- x$.stageResults$getGMax()
+            .assertIsValidAssumedStDevs(assumedStDevs, gMax)
+
             functionCall$assumedStDevs <- assumedStDevs
         } else {
             assumedStDev <- eval.parent(functionCall$assumedStDev)
