@@ -13,8 +13,8 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 6801 $
-## |  Last changed: $Date: 2023-02-06 15:29:57 +0100 (Mon, 06 Feb 2023) $
+## |  File version: $Revision: 7620 $
+## |  Last changed: $Date: 2024-02-09 12:57:37 +0100 (Fr, 09 Feb 2024) $
 ## |  Last changed by: $Author: pahlke $
 ## |
 
@@ -32,7 +32,7 @@ NULL
 #'
 #' @description
 #' Basic class for trial designs.
-#' 
+#'
 #' @template field_kMax
 #' @template field_alpha
 #' @template field_stages
@@ -48,8 +48,9 @@ NULL
 #' \code{TrialDesign} is the basic class for
 #' \itemize{
 #'   \item \code{\link{TrialDesignFisher}},
-#'   \item \code{\link{TrialDesignGroupSequential}}, and
-#'   \item \code{\link{TrialDesignInverseNormal}}.
+#'   \item \code{\link{TrialDesignGroupSequential}},
+#'   \item \code{\link{TrialDesignInverseNormal}}, and
+#'   \item \code{\link{TrialDesignConditionalDunnett}}.
 #' }
 #'
 #' @include class_core_parameter_set.R
@@ -100,25 +101,6 @@ TrialDesign <- setRefClass("TrialDesign",
 
             .plotSettings <<- PlotSettings()
 
-            if (inherits(.self, "TrialDesignConditionalDunnett")) {
-                .parameterNames <<- C_PARAMETER_NAMES
-            } else {
-                .parameterNames <<- .getSubListByNames(.getParameterNames(design = .self), c(
-                    "stages",
-                    "kMax",
-                    "alpha",
-                    "informationRates",
-                    "userAlphaSpending",
-                    "criticalValues",
-                    "stageLevels",
-                    "alphaSpent",
-                    "bindingFutility",
-                    "tolerance"
-                ))
-            }
-
-            .parameterFormatFunctions <<- C_PARAMETER_FORMAT_FUNCTIONS
-
             .initStages()
         },
         show = function(showType = 1, digits = NA_integer_) {
@@ -198,12 +180,24 @@ TrialDesign <- setRefClass("TrialDesign",
 #' @description
 #' Class for trial design characteristics.
 #'
+#' @template field_nFixed
+#' @template field_shift
+#' @template field_inflationFactor
+#' @template field_stages
+#' @template field_information
+#' @template field_power
+#' @template field_rejectionProbabilities
+#' @template field_futilityProbabilities
+#' @template field_averageSampleNumber1
+#' @template field_averageSampleNumber01
+#' @template field_averageSampleNumber0
+#'
 #' @details
 #' \code{TrialDesignCharacteristics} contains all fields required to collect the characteristics of a design.
-#' This object should not be created directly; use \code{\link[=getDesignCharacteristics]{getDesignCharacteristics()}}
+#' This object should not be created directly; use \code{getDesignCharacteristics}
 #' with suitable arguments to create it.
 #'
-#' @seealso \code{\link[=getDesignCharacteristics]{getDesignCharacteristics()}} for getting the design characteristics.
+#' @seealso \code{\link{getDesignCharacteristics}} for getting the design characteristics.
 #'
 #' @include class_core_parameter_set.R
 #' @include f_core_constants.R
@@ -232,9 +226,6 @@ TrialDesignCharacteristics <- setRefClass("TrialDesignCharacteristics",
     methods = list(
         initialize = function(design, ...) {
             callSuper(.design = design, ...)
-            .parameterNames <<- .getParameterNames(design = design)
-            .parameterFormatFunctions <<- C_PARAMETER_FORMAT_FUNCTIONS
-            .parameterFormatFunctions[["nFixed"]] <<- ".formatProbabilities"
             .initStages()
         },
         show = function(showType = 1, digits = NA_integer_) {
@@ -279,6 +270,31 @@ TrialDesignCharacteristics <- setRefClass("TrialDesignCharacteristics",
     )
 )
 
+#'
+#' @title
+#' Trial Design Characteristics Printing
+#'
+#' @param x The trial design characteristics object.
+#' @param markdown If \code{TRUE}, the object \code{x} will be printed using markdown syntax;
+#'        normal representation will be used otherwise (default is \code{FALSE})
+#' @param showDesign Show the design print output above the design characteristics, default is \code{TRUE}.
+#' @inheritParams param_three_dots_plot
+#'
+#' @description
+#' Prints the design characteristics object.
+#'
+#' @details
+#' Generic function to print all kinds of design characteristics.
+#'
+#' @export
+#'
+print.TrialDesignCharacteristics <- function(x, ..., markdown = FALSE, showDesign = TRUE) {
+    if (showDesign) {
+        print.ParameterSet(x$.design, ..., markdown = markdown)
+    }
+    print.ParameterSet(x, ..., markdown = markdown)
+}
+
 #'
 #' @title
 #' Coerce TrialDesignCharacteristics to a Data Frame
@@ -310,12 +326,12 @@ as.data.frame.TrialDesignCharacteristics <- function(x, row.names = NULL,
     } else {
         parameterNamesToBeExcluded <- c("inflationFactor")
     }
-    return(.getAsDataFrame(parameterSet = x, 
+    return(.getAsDataFrame(
+        parameterSet = x,
         parameterNames = parameterNamesToBeExcluded,
-        niceColumnNamesEnabled = niceColumnNamesEnabled, 
+        niceColumnNamesEnabled = niceColumnNamesEnabled,
         includeAllParameters = includeAllParameters,
-        handleParameterNamesAsToBeExcluded = TRUE,
-        tableColumnNames = .getTableColumnNames(design = x$.design)
+        handleParameterNamesAsToBeExcluded = TRUE
     ))
 }
 
@@ -327,7 +343,7 @@ as.data.frame.TrialDesignCharacteristics <- function(x, row.names = NULL,
 #'
 #' @description
 #' Trial design for Fisher's combination test.
-#' 
+#'
 #' @template field_kMax
 #' @template field_alpha
 #' @template field_stages
@@ -338,20 +354,20 @@ as.data.frame.TrialDesignCharacteristics <- function(x, row.names = NULL,
 #' @template field_alphaSpent
 #' @template field_bindingFutility
 #' @template field_tolerance
-#' @field method "equalAlpha", "fullAlpha", "noInteraction", or "userDefinedAlpha", default is "equalAlpha" (for details, see Wassmer, 1999)
-#' @field alpha0Vec Stopping for futility bounds for stage-wise p-values.
-#' @field scale Is a numeric vector of length \code{kMax}-1 that applies to Fisher's design with unequally spaced information rates.
-#' @field nonStochasticCurtailment Logical. If \code{TRUE}, the stopping rule is based on the phenomenon of non-stochastic curtailment rather than stochastic reasoning.
+#' @template field_method
+#' @template field_alpha0Vec
+#' @template field_scale
+#' @template field_nonStochasticCurtailment
 #' @template field_sided
-#' @field simAlpha The observed alpha error, if simulations have been performed. Is a numeric vector of length 1.
+#' @template field_simAlpha
 #' @template field_iterations
 #' @template field_seed
 #'
 #' @details
-#' This object should not be created directly; use \code{\link[=getDesignFisher]{getDesignFisher()}}
+#' This object should not be created directly; use \code{\link{getDesignFisher}}
 #' with suitable arguments to create a Fisher combination test design.
 #'
-#' @seealso \code{\link[=getDesignFisher]{getDesignFisher()}} for creating a Fisher combination test design.
+#' @seealso \code{\link{getDesignFisher}} for creating a Fisher combination test design.
 #'
 #' @include class_core_parameter_set.R
 #' @include class_core_plot_settings.R
@@ -396,21 +412,6 @@ TrialDesignFisher <- setRefClass(C_CLASS_NAME_TRIAL_DESIGN_FISHER,
                 tolerance = tolerance
             )
 
-            .parameterNames <<- c(.parameterNames, .getSubListByNames(
-                .getParameterNames(design = .self), c(
-                    "method",
-                    "alpha0Vec",
-                    "scale",
-                    "nonStochasticCurtailment",
-                    "sided",
-                    "simAlpha",
-                    "iterations",
-                    "seed"
-                )
-            ))
-
-            .parameterFormatFunctions$criticalValues <<- ".formatCriticalValuesFisher"
-
             .initParameterTypes()
             .setParameterType("iterations", C_PARAM_NOT_APPLICABLE)
             .setParameterType("seed", C_PARAM_NOT_APPLICABLE)
@@ -487,7 +488,7 @@ TrialDesignFisher <- setRefClass(C_CLASS_NAME_TRIAL_DESIGN_FISHER,
 #'
 #' @description
 #' Trial design for inverse normal method.
-#' 
+#'
 #' @template field_kMax
 #' @template field_alpha
 #' @template field_stages
@@ -598,8 +599,6 @@ TrialDesignInverseNormal <- setRefClass(C_CLASS_NAME_TRIAL_DESIGN_INVERSE_NORMAL
                 delayedInformation = delayedInformation
             )
 
-            .initParameterNames()
-            .parameterFormatFunctions$criticalValues <<- ".formatCriticalValues"
             .initParameterTypes()
             .initStages()
 
@@ -608,32 +607,6 @@ TrialDesignInverseNormal <- setRefClass(C_CLASS_NAME_TRIAL_DESIGN_INVERSE_NORMAL
             .setParameterType("decisionCriticalValues", C_PARAM_NOT_APPLICABLE)
             .setParameterType("reversalProbabilities", C_PARAM_NOT_APPLICABLE)
         },
-        .initParameterNames = function() {
-            .parameterNames <<- c(.parameterNames, .getSubListByNames(
-                .getParameterNames(design = .self), c(
-                    "beta",
-                    "betaSpent",
-                    "sided",
-                    "futilityBounds",
-                    "typeOfDesign",
-                    "deltaWT",
-                    "deltaPT1",
-                    "deltaPT0",
-                    "optimizationCriterion",
-                    "gammaA",
-                    "gammaB",
-                    "typeBetaSpending",
-                    "userBetaSpending",
-                    "power",
-                    "twoSidedPower",
-                    "constantBoundsHP",
-                    "betaAdjustment",
-                    "delayedInformation",
-                    "decisionCriticalValues",
-                    "reversalProbabilities"
-                )
-            ))
-        },
         .formatComparisonResult = function(x) {
             if (is.null(x) || length(x) == 0 || !is.numeric(x)) {
                 return(x)
@@ -812,7 +785,7 @@ TrialDesignInverseNormal <- setRefClass(C_CLASS_NAME_TRIAL_DESIGN_INVERSE_NORMAL
 #'
 #' @description
 #' Trial design for group sequential design.
-#' 
+#'
 #' @template field_kMax
 #' @template field_alpha
 #' @template field_stages
@@ -864,7 +837,6 @@ TrialDesignGroupSequential <- setRefClass(
     methods = list(
         initialize = function(...) {
             callSuper(...)
-            .parameterFormatFunctions$criticalValues <<- ".formatCriticalValues"
             .initStages()
         },
         show = function(showType = 1, digits = NA_integer_) {
@@ -882,7 +854,7 @@ TrialDesignGroupSequential <- setRefClass(
 #'
 #' @description
 #' Trial design for conditional Dunnett tests.
-#' 
+#'
 #' @template field_kMax
 #' @template field_alpha
 #' @template field_stages
@@ -893,14 +865,12 @@ TrialDesignGroupSequential <- setRefClass(
 #' @template field_alphaSpent
 #' @template field_bindingFutility
 #' @template field_tolerance
-#' @template field_informationAtInterim 
-#' @field secondStageConditioning Logical. The way the second stage p-values are calculated within 
-#' the closed system of hypotheses. If secondStageConditioning = FALSE is specified, the unconditional adjusted p-values are used, 
-#' otherwise conditional adjusted p-values are calculated, default is secondStageConditioning = TRUE.
+#' @template field_informationAtInterim
+#' @template field_secondStageConditioning
 #' @template field_sided
 #'
 #' @details
-#' This object should not be created directly; use \code{\link[=getDesignConditionalDunnett]{getDesignConditionalDunnett()}}
+#' This object should not be created directly; use \code{\link{getDesignConditionalDunnett}}
 #' with suitable arguments to create a conditional Dunnett test design.
 #'
 #' @include class_core_parameter_set.R
@@ -911,8 +881,8 @@ TrialDesignGroupSequential <- setRefClass(
 #'
 #' @importFrom methods new
 #'
-#' @seealso \code{\link[=getDesignConditionalDunnett]{getDesignConditionalDunnett()}} for creating a conditional Dunnett test design.
-
+#' @seealso \code{\link{getDesignConditionalDunnett}} for creating a conditional Dunnett test design.
+#'
 TrialDesignConditionalDunnett <- setRefClass(
     C_CLASS_NAME_TRIAL_DESIGN_CONDITIONAL_DUNNETT,
     contains = "TrialDesign",
@@ -979,7 +949,7 @@ TrialDesignConditionalDunnett <- setRefClass(
 #' For performing the conditional Dunnett test the design must be defined through this function.
 #' You can define the information fraction and the way of how to compute the second stage
 #' p-values only in the design definition, and not in the analysis call.\cr
-#' See \code{\link[=getClosedConditionalDunnettTestResults]{getClosedConditionalDunnettTestResults()}} 
+#' See \code{\link[=getClosedConditionalDunnettTestResults]{getClosedConditionalDunnettTestResults()}}
 #' for an example and Koenig et al. (2008) and
 #' Wassmer & Brannath (2016), chapter 11 for details of the test procedure.
 #'
@@ -1047,9 +1017,9 @@ getDesignConditionalDunnett <- function(alpha = 0.025, # C_ALPHA_DEFAULT
 #'
 #' Note that \code{\link[=param_nMax]{nMax}} is not an argument that it passed to \code{ggplot2}.
 #' Rather, the underlying calculations (e.g. power for different theta's or average sample size) are based
-#' on calls to function \code{\link[=getPowerAndAverageSampleNumber]{getPowerAndAverageSampleNumber()}} 
+#' on calls to function \code{\link[=getPowerAndAverageSampleNumber]{getPowerAndAverageSampleNumber()}}
 #' which has argument \code{\link[=param_nMax]{nMax}}.
-#' I.e., \code{\link[=param_nMax]{nMax}} is not an argument to ggplot2 but to 
+#' I.e., \code{\link[=param_nMax]{nMax}} is not an argument to ggplot2 but to
 #' \code{\link[=getPowerAndAverageSampleNumber]{getPowerAndAverageSampleNumber()}}
 #' which is called prior to plotting.
 #'
@@ -1117,6 +1087,12 @@ plot.TrialDesign <- function(x, y, ..., main = NA_character_,
     return(.createPlotResultObject(plotList, grid))
 }
 
+#' @rdname plot.TrialDesign
+#' @export
+plot.TrialDesignCharacteristics <- function(x, y, ...) {
+    plot(x = x$.design, y = y, ...)
+}
+
 .plotTrialDesign <- function(..., x, y, main,
         xlab, ylab, type, palette,
         theta, nMax, plotPointsEnabled,
@@ -1204,10 +1180,10 @@ as.data.frame.TrialDesign <- function(x, row.names = NULL,
     } else {
         parameterNames <- x$.getParametersToShow()
     }
-    return(.getAsDataFrame(parameterSet = x, 
+    return(.getAsDataFrame(
+        parameterSet = x,
         parameterNames = parameterNames,
         niceColumnNamesEnabled = niceColumnNamesEnabled,
-        includeAllParameters = includeAllParameters,
-        tableColumnNames = .getTableColumnNames(design = x)
+        includeAllParameters = includeAllParameters
     ))
 }
