@@ -13,8 +13,8 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 7509 $
-## |  Last changed: $Date: 2023-12-20 16:06:21 +0100 (Mi, 20 Dez 2023) $
+## |  File version: $Revision: 7672 $
+## |  Last changed: $Date: 2024-02-27 10:42:41 +0100 (Di, 27 Feb 2024) $
 ## |  Last changed by: $Author: pahlke $
 ## |
 
@@ -107,8 +107,6 @@ SimulationResults <- setRefClass("SimulationResults",
             callSuper(.design = design, .showStatistics = showStatistics, ...)
 
             .plotSettings <<- PlotSettings()
-            .parameterNames <<- .getParameterNames(design = design, designPlan = .self)
-            .parameterFormatFunctions <<- C_PARAMETER_FORMAT_FUNCTIONS
         },
         getPlotSettings = function() {
             return(.plotSettings)
@@ -204,7 +202,7 @@ SimulationResults <- setRefClass("SimulationResults",
                             "numberOfSubjects",
                             "eventsPerStage1",
                             "eventsPerStage2",
-                            "eventsPerStage",
+                            "cumulativeEventsPerStage",
                             "testStatistic",
                             "logRankStatistic",
                             "hazardRatioEstimateLR"
@@ -236,7 +234,8 @@ SimulationResults <- setRefClass("SimulationResults",
                         params <- c(
                             "effectMeasure",
                             "numberOfEvents",
-                            "singleNumberOfEventsPerStage",
+                            "singleEventsPerArmAndStage",
+                            "singleEventsPerSubsetAndStage",
                             "testStatistic",
                             "conditionalCriticalValue",
                             "rejectPerStage",
@@ -260,7 +259,7 @@ SimulationResults <- setRefClass("SimulationResults",
                     parameterValues2 <- .getVariedParameterValues(variedParameterName2)
 
                     for (parameterName in params) {
-                        paramCaption <- .parameterNames[[parameterName]]
+                        paramCaption <- .getParameterCaption(parameterName, .self)
                         if (is.null(paramCaption)) {
                             paramCaption <- paste0("%", parameterName, "%")
                         }
@@ -293,7 +292,7 @@ SimulationResults <- setRefClass("SimulationResults",
                             }
                             if (parameterName == "subjectsActiveArm" && variedParameterName2 == "armNumber") {
                                 parameterName2 <- "subjectsControlArm"
-                                paramCaption2 <- .parameterNames[[parameterName2]]
+                                paramCaption2 <- .getParameterCaption(parameterName2, .self)
                                 if (is.null(paramCaption2)) {
                                     paramCaption2 <- paste0("%", parameterName2, "%")
                                 }
@@ -517,8 +516,8 @@ SimulationResults <- setRefClass("SimulationResults",
         .getParametersToShow = function() {
             parametersToShow <- .getVisibleFieldNames()
             y <- c(
-                "eventsPerStage",
-                "overallEventsPerStage",
+                "singleEventsPerStage",
+                "cumulativeEventsPerStage",
                 "iterations",
                 "overallReject", # base
                 "rejectAtLeastOne",
@@ -541,7 +540,8 @@ SimulationResults <- setRefClass("SimulationResults",
                 "expectedNumberOfSubjects",
                 "expectedNumberOfEvents",
                 "sampleSizes",
-                "singleNumberOfEventsPerStage",
+                "singleEventsPerArmAndStage",
+                "singleEventsPerSubsetAndStage",
                 "conditionalPowerAchieved" # base
             )
             parametersToShow <- c(parametersToShow[!(parametersToShow %in% y)], y[y %in% parametersToShow])
@@ -551,7 +551,8 @@ SimulationResults <- setRefClass("SimulationResults",
             return(FALSE)
         },
         getRawDataResults = function(maxNumberOfIterations = NA_integer_) {
-            return(.getSimulationParametersFromRawData(.self$.data,
+            return(.getSimulationParametersFromRawData(
+                data = .self$.data,
                 variantName = .getVariedParameterName(),
                 maxNumberOfIterations = maxNumberOfIterations
             ))
@@ -1044,7 +1045,7 @@ SimulationResultsBaseSurvival <- setRefClass("SimulationResultsBaseSurvival",
             generatedParams <- c(
                 "iterations",
                 "expectedNumberOfEvents",
-                "eventsPerStage",
+                "cumulativeEventsPerStage",
                 "overallReject",
                 "rejectPerStage",
                 "futilityPerStage",
@@ -1108,8 +1109,8 @@ SimulationResultsBaseSurvival <- setRefClass("SimulationResultsBaseSurvival",
 #' @template field_numberOfSubjects
 #' @template field_numberOfSubjects1
 #' @template field_numberOfSubjects2
-#' @template field_eventsPerStage
-#' @template field_overallEventsPerStage
+#' @template field_singleEventsPerStage
+#' @template field_cumulativeEventsPerStage
 #' @template field_expectedNumberOfSubjects
 #' @template field_rejectPerStage
 #' @template field_overallReject
@@ -1167,8 +1168,10 @@ SimulationResultsSurvival <- setRefClass("SimulationResultsSurvival",
         numberOfSubjects = "matrix",
         numberOfSubjects1 = "matrix",
         numberOfSubjects2 = "matrix",
-        eventsPerStage = "matrix",
-        overallEventsPerStage = "matrix",
+        eventsPerStage = "matrix", # deprecated
+        overallEventsPerStage = "matrix", # deprecated
+        singleEventsPerStage = "matrix",
+        cumulativeEventsPerStage = "matrix",
         expectedNumberOfSubjects = "numeric",
         rejectPerStage = "matrix",
         overallReject = "numeric",
@@ -1180,8 +1183,6 @@ SimulationResultsSurvival <- setRefClass("SimulationResultsSurvival",
             generatedParams <- c(
                 "hazardRatio",
                 "iterations",
-                "eventsPerStage",
-                "singleNumberOfEventsPerStage",
                 "expectedNumberOfEvents",
                 "eventsNotAchieved",
                 "numberOfSubjects",
@@ -1194,6 +1195,12 @@ SimulationResultsSurvival <- setRefClass("SimulationResultsSurvival",
                 "studyDuration",
                 "allocationRatioPlanned"
             )
+            if (inherits(.self, "SimulationResultsMultiArmSurvival")) {
+                generatedParams <- c(generatedParams, 
+                    "cumulativeEventsPerStage", "singleEventsPerArmAndStage")
+            } else {
+                generatedParams <- c(generatedParams, "singleEventsPerSubsetAndStage")
+            }
             if (design$kMax > 2) {
                 generatedParams <- c(generatedParams, "futilityStop")
             }
@@ -1204,6 +1211,8 @@ SimulationResultsSurvival <- setRefClass("SimulationResultsSurvival",
             .setParameterType("numberOfSubjects2", C_PARAM_NOT_APPLICABLE)
             .setParameterType("median1", C_PARAM_NOT_APPLICABLE)
             .setParameterType("median2", C_PARAM_NOT_APPLICABLE)
+            .setParameterType("eventsPerStage", C_PARAM_NOT_APPLICABLE)
+            .setParameterType("overallEventsPerStage", C_PARAM_NOT_APPLICABLE)
         }
     )
 )
@@ -1250,6 +1259,9 @@ SimulationResultsSurvival <- setRefClass("SimulationResultsSurvival",
 #' @template field_successPerStage
 #' @template field_eventsPerStage
 #' @template field_singleNumberOfEventsPerStage
+#' @template field_singleEventsPerArmAndStage
+#' @template field_singleEventsPerStage
+#' @template field_cumulativeEventsPerStage
 #' @template field_conditionalPowerAchieved
 #'
 #' @details
@@ -1291,8 +1303,11 @@ SimulationResultsMultiArmSurvival <- setRefClass("SimulationResultsMultiArmSurvi
         rejectAtLeastOne = "numeric",
         rejectedArmsPerStage = "array",
         successPerStage = "matrix",
-        eventsPerStage = "array",
-        singleNumberOfEventsPerStage = "array",
+        eventsPerStage = "array", # deprecated
+        singleEventsPerStage = "array",
+        cumulativeEventsPerStage = "array", 
+        singleEventsPerArmAndStage = "array",
+        singleNumberOfEventsPerStage = "array", # deprecated
         conditionalPowerAchieved = "matrix"
     ),
     methods = list(
@@ -1560,6 +1575,7 @@ SimulationResultsEnrichmentRates <- setRefClass("SimulationResultsEnrichmentRate
 #' @template field_successPerStage
 #' @template field_eventsPerStage
 #' @template field_singleNumberOfEventsPerStage
+#' @template field_singleEventsPerSubsetAndStage
 #' @template field_conditionalPowerAchieved
 #'
 #' @details
@@ -1599,8 +1615,9 @@ SimulationResultsEnrichmentSurvival <- setRefClass("SimulationResultsEnrichmentS
         rejectAtLeastOne = "numeric",
         rejectedPopulationsPerStage = "array",
         successPerStage = "matrix",
-        eventsPerStage = "array",
-        singleNumberOfEventsPerStage = "array",
+        eventsPerStage = "array", # deprecated
+        singleEventsPerSubsetAndStage = "array",
+        singleNumberOfEventsPerStage = "array", # deprecated
         conditionalPowerAchieved = "matrix"
     ),
     methods = list(
