@@ -13,8 +13,8 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 6517 $
-## |  Last changed: $Date: 2022-08-22 16:26:44 +0200 (Mo, 22 Aug 2022) $
+## |  File version: $Revision: 7408 $
+## |  Last changed: $Date: 2023-11-09 10:36:19 +0100 (Do, 09 Nov 2023) $
 ## |  Last changed by: $Author: pahlke $
 ## |
 
@@ -22,7 +22,7 @@
 NULL
 
 .getGroupSequentialProbabilities <- function(decisionMatrix, informationRates) {
-    return(getGroupSequentialProbabilitiesCpp(decisionMatrix, informationRates))
+    return(.getGroupSequentialProbabilitiesCpp(decisionMatrix, informationRates))
 }
 
 #' @title
@@ -51,6 +51,8 @@ NULL
 #'
 #' @template examples_get_group_sequential_probabilities
 #'
+#' @return Returns a numeric matrix containing the probabilities described in the details section.
+#'
 #' @export
 #'
 getGroupSequentialProbabilities <- function(decisionMatrix, informationRates) {
@@ -239,7 +241,6 @@ getGroupSequentialProbabilities <- function(decisionMatrix, informationRates) {
     return(invisible(design))
 }
 
-
 .validateBaseParameters <- function(design, twoSidedWarningForDefaultValues = TRUE) {
     if (.isDefinedArgument(design$kMax)) {
         .assertDesignParameterExists(design, "kMax", C_KMAX_DEFAULT)
@@ -443,7 +444,7 @@ getGroupSequentialProbabilities <- function(decisionMatrix, informationRates) {
 #
 .getDesignGroupSequentialWangAndTsiatis <- function(design) {
     if (design$typeOfDesign == C_TYPE_OF_DESIGN_P) {
-        design$criticalValues <- getDesignGroupSequentialPocockCpp(
+        design$criticalValues <- .getDesignGroupSequentialPocockCpp(
             design$kMax,
             design$alpha,
             design$sided,
@@ -453,7 +454,7 @@ getGroupSequentialProbabilities <- function(decisionMatrix, informationRates) {
             design$tolerance
         )
     } else if (design$typeOfDesign == C_TYPE_OF_DESIGN_OF) {
-        design$criticalValues <- getDesignGroupSequentialOBrienAndFlemingCpp(
+        design$criticalValues <- .getDesignGroupSequentialOBrienAndFlemingCpp(
             design$kMax,
             design$alpha,
             design$sided,
@@ -463,7 +464,7 @@ getGroupSequentialProbabilities <- function(decisionMatrix, informationRates) {
             design$tolerance
         )
     } else {
-        design$criticalValues <- getDesignGroupSequentialDeltaWTCpp(
+        design$criticalValues <- .getDesignGroupSequentialDeltaWTCpp(
             design$kMax,
             design$alpha,
             design$sided,
@@ -480,7 +481,7 @@ getGroupSequentialProbabilities <- function(decisionMatrix, informationRates) {
 }
 
 .getDesignGroupSequentialPampallonaTsiatis <- function(design) {
-    cppResult <- getDesignGroupSequentialPampallonaTsiatisCpp(
+    cppResult <- .getDesignGroupSequentialPampallonaTsiatisCpp(
         design$tolerance, design$beta, design$alpha, design$kMax,
         design$deltaPT0, design$deltaPT1, design$informationRates,
         design$sided, design$bindingFutility
@@ -564,9 +565,11 @@ getGroupSequentialProbabilities <- function(decisionMatrix, informationRates) {
     )
 }
 
-#
-# Haybittle & Peto design
-#
+#'
+#' Haybittle & Peto design
+#'
+#' @noRd
+#'
 .getDesignGroupSequentialHaybittleAndPeto <- function(design) {
     scale <- .getOneDimensionalRoot(
         function(scale) {
@@ -602,7 +605,6 @@ getGroupSequentialProbabilities <- function(decisionMatrix, informationRates) {
     return(invisible(design))
 }
 
-
 .getOptimumDesign <- function(deltaWT, design) {
     scale <- .getOneDimensionalRoot(
         function(scale) {
@@ -647,9 +649,11 @@ getGroupSequentialProbabilities <- function(decisionMatrix, informationRates) {
     return(y)
 }
 
-#
-# Optimum design within Wang and Tsiatis class
-#
+#'
+#' Optimum design within Wang and Tsiatis class
+#'
+#' @noRd
+#'
 .getDesignGroupSequentialWangAndTsiatisOptimum <- function(design) {
     .assertDesignParameterExists(design, "optimizationCriterion", C_OPTIMIZATION_CRITERION_DEFAULT)
     .assertIsOptimizationCriterion(design$optimizationCriterion)
@@ -663,7 +667,7 @@ getGroupSequentialProbabilities <- function(decisionMatrix, informationRates) {
     design$.setParameterType("deltaWT", C_PARAM_GENERATED)
 
     # Recalculation of design characteristics with rounded design$deltaWT
-    design$criticalValues <- getDesignGroupSequentialDeltaWTCpp(
+    design$criticalValues <- .getDesignGroupSequentialDeltaWTCpp(
         design$kMax,
         design$alpha,
         design$sided,
@@ -682,11 +686,13 @@ getGroupSequentialProbabilities <- function(decisionMatrix, informationRates) {
     return(invisible(design))
 }
 
-#
-# alpha spending approaches
-#
+#'
+#' Alpha spending approaches
+#'
+#' @noRd
+#'
 .getDesignGroupSequentialAlphaSpending <- function(design, userFunctionCallEnabled) {
-    design$criticalValues <- getDesignGroupSequentialAlphaSpendingCpp(
+    design$criticalValues <- .getDesignGroupSequentialAlphaSpendingCpp(
         design$kMax,
         design$alpha,
         design$gammaA,
@@ -701,9 +707,11 @@ getGroupSequentialProbabilities <- function(decisionMatrix, informationRates) {
     return(.getDesignGroupSequentialBetaSpendingApproaches(design, userFunctionCallEnabled))
 }
 
-#
-# User defined alpha spending approach
-#
+#'
+#' User defined alpha spending approach
+#'
+#' @noRd
+#'
 .getDesignGroupSequentialUserDefinedAlphaSpending <- function(design, userFunctionCallEnabled) {
     design$criticalValues <- rep(NA_real_, design$kMax)
     if (design$typeOfDesign == C_TYPE_OF_DESIGN_NO_EARLY_EFFICACY) {
@@ -714,7 +722,7 @@ getGroupSequentialProbabilities <- function(decisionMatrix, informationRates) {
         design$criticalValues[1:(design$kMax - 1)] <- C_QNORM_THRESHOLD
         design$criticalValues[design$kMax] <- .getOneMinusQNorm(design$alpha / design$sided)
     } else {
-        design$criticalValues <- getDesignGroupSequentialUserDefinedAlphaSpendingCpp(
+        design$criticalValues <- .getDesignGroupSequentialUserDefinedAlphaSpendingCpp(
             design$kMax, design$userAlphaSpending, design$sided,
             design$informationRates, design$bindingFutility, design$futilityBounds, design$tolerance
         )
@@ -728,11 +736,12 @@ getGroupSequentialProbabilities <- function(decisionMatrix, informationRates) {
     return(invisible(.getDesignGroupSequentialBetaSpendingApproaches(design, userFunctionCallEnabled)))
 }
 
-#
-# Only for alpha spending approaches
-#
+#'
+#' Only for alpha spending approaches
+#'
+#' @noRd
+#'
 .getDesignGroupSequentialBetaSpendingApproaches <- function(design, userFunctionCallEnabled) {
-
     # beta spending approaches (additional to alpha spending)!
     if (.isBetaSpendingDesignType(design$typeBetaSpending,
             userDefinedBetaSpendingIncluded = FALSE, noneIncluded = FALSE
@@ -752,12 +761,14 @@ getGroupSequentialProbabilities <- function(decisionMatrix, informationRates) {
     return(c(vec, rep(NA_real_, n - length(vec))))
 }
 
-#
-# Beta spending approaches (additional to alpha spending)
-# Find shift with beta spending such that last critical values coincide
-#
+#'
+#' Beta spending approaches (additional to alpha spending)
+#' Find shift with beta spending such that last critical values coincide
+#'
+#' @noRd
+#'
 .getDesignGroupSequentialBetaSpending <- function(design, userFunctionCallEnabled) {
-    cppResult <- getDesignGroupSequentialBetaSpendingCpp(
+    cppResult <- .getDesignGroupSequentialBetaSpendingCpp(
         design$criticalValues,
         design$kMax,
         design$userAlphaSpending,
@@ -792,11 +803,13 @@ getGroupSequentialProbabilities <- function(decisionMatrix, informationRates) {
     return(invisible(design))
 }
 
-#
-# User defined beta spending.
-#
-# Find shift with beta spending such that last critical values coincide
-#
+#'
+#' User defined beta spending
+#'
+#' Find shift with beta spending such that last critical values coincide
+#'
+#' @noRd
+#'
 .getDesignGroupSequentialUserDefinedBetaSpending <- function(design) {
     if (design$typeBetaSpending != C_TYPE_OF_DESIGN_BS_USER) {
         stop(
@@ -805,7 +818,7 @@ getGroupSequentialProbabilities <- function(decisionMatrix, informationRates) {
         )
     }
 
-    cppResult <- getDesignGroupSequentialUserDefinedBetaSpendingCpp(
+    cppResult <- .getDesignGroupSequentialUserDefinedBetaSpendingCpp(
         design$criticalValues,
         design$kMax,
         design$userAlphaSpending,
@@ -836,7 +849,11 @@ getGroupSequentialProbabilities <- function(decisionMatrix, informationRates) {
     return(invisible(design))
 }
 
-# calculate stopping, rejection and futility probabilities for delayed response design
+#'
+#' Calculate stopping, rejection and futility probabilities for delayed response design
+#'
+#' @noRd
+#'
 .calculateDecisionProbabilities <- function(sqrtShift, informationRates, delayedInformation,
         contRegionUpper, contRegionLower, decisionCriticalValues) {
     kMax <- length(informationRates)
@@ -855,20 +872,22 @@ getGroupSequentialProbabilities <- function(decisionMatrix, informationRates) {
             )
             if (stage == 1) {
                 probs1 <- .getGroupSequentialProbabilities(
-                    matrix(c(
-                        contRegionUpper[stage] - sqrtShift * sqrt(informationRatesUponDelay[1]),
-                        decisionCriticalValues[stage] - sqrtShift * sqrt(informationRatesUponDelay[2]),
-                        C_UPPER_BOUNDS_DEFAULT, C_UPPER_BOUNDS_DEFAULT
-                    ),
-                    nrow = 2, byrow = TRUE
+                    matrix(
+                        c(
+                            contRegionUpper[stage] - sqrtShift * sqrt(informationRatesUponDelay[1]),
+                            decisionCriticalValues[stage] - sqrtShift * sqrt(informationRatesUponDelay[2]),
+                            C_UPPER_BOUNDS_DEFAULT, C_UPPER_BOUNDS_DEFAULT
+                        ),
+                        nrow = 2, byrow = TRUE
                     ), informationRatesUponDelay
                 )
                 probs2 <- .getGroupSequentialProbabilities(
-                    matrix(c(
-                        -C_UPPER_BOUNDS_DEFAULT, decisionCriticalValues[stage] - sqrtShift * sqrt(informationRatesUponDelay[2]),
-                        contRegionLower[stage] - sqrtShift * sqrt(informationRatesUponDelay[1]), C_UPPER_BOUNDS_DEFAULT
-                    ),
-                    nrow = 2, byrow = TRUE
+                    matrix(
+                        c(
+                            -C_UPPER_BOUNDS_DEFAULT, decisionCriticalValues[stage] - sqrtShift * sqrt(informationRatesUponDelay[2]),
+                            contRegionLower[stage] - sqrtShift * sqrt(informationRatesUponDelay[1]), C_UPPER_BOUNDS_DEFAULT
+                        ),
+                        nrow = 2, byrow = TRUE
                     ), informationRatesUponDelay
                 )
                 rejectionProbabilities[stage] <- probs1[2, stage + 1] - probs1[1, stage + 1] +
@@ -878,25 +897,27 @@ getGroupSequentialProbabilities <- function(decisionMatrix, informationRates) {
                 stoppingProbabilities[stage] <- probs2[2, stage] + 1 - probs1[1, stage]
             } else if (stage < kMax) {
                 probs1 <- .getGroupSequentialProbabilities(
-                    matrix(c(
-                        contRegionLower[1:(stage - 1)] - sqrtShift * sqrt(informationRatesUponDelay[1:(stage - 1)]),
-                        contRegionUpper[stage] - sqrtShift * sqrt(informationRatesUponDelay[stage]),
-                        decisionCriticalValues[stage] - sqrtShift * sqrt(informationRatesUponDelay[stage + 1]),
-                        contRegionUpper[1:(stage - 1)] - sqrtShift * sqrt(informationRatesUponDelay[1:(stage - 1)]),
-                        C_UPPER_BOUNDS_DEFAULT, C_UPPER_BOUNDS_DEFAULT
-                    ),
-                    nrow = 2, byrow = TRUE
+                    matrix(
+                        c(
+                            contRegionLower[1:(stage - 1)] - sqrtShift * sqrt(informationRatesUponDelay[1:(stage - 1)]),
+                            contRegionUpper[stage] - sqrtShift * sqrt(informationRatesUponDelay[stage]),
+                            decisionCriticalValues[stage] - sqrtShift * sqrt(informationRatesUponDelay[stage + 1]),
+                            contRegionUpper[1:(stage - 1)] - sqrtShift * sqrt(informationRatesUponDelay[1:(stage - 1)]),
+                            C_UPPER_BOUNDS_DEFAULT, C_UPPER_BOUNDS_DEFAULT
+                        ),
+                        nrow = 2, byrow = TRUE
                     ), informationRatesUponDelay
                 )
                 probs2 <- .getGroupSequentialProbabilities(
-                    matrix(c(
-                        contRegionLower[1:(stage - 1)] - sqrtShift *
-                            sqrt(informationRatesUponDelay[1:(stage - 1)]), -C_UPPER_BOUNDS_DEFAULT,
-                        decisionCriticalValues[stage] - sqrtShift * sqrt(informationRatesUponDelay[stage + 1]),
-                        contRegionUpper[1:(stage - 1)] - sqrtShift * sqrt(informationRatesUponDelay[1:(stage - 1)]),
-                        contRegionLower[stage] - sqrtShift * sqrt(informationRatesUponDelay[stage]), C_UPPER_BOUNDS_DEFAULT
-                    ),
-                    nrow = 2, byrow = TRUE
+                    matrix(
+                        c(
+                            contRegionLower[1:(stage - 1)] - sqrtShift *
+                                sqrt(informationRatesUponDelay[1:(stage - 1)]), -C_UPPER_BOUNDS_DEFAULT,
+                            decisionCriticalValues[stage] - sqrtShift * sqrt(informationRatesUponDelay[stage + 1]),
+                            contRegionUpper[1:(stage - 1)] - sqrtShift * sqrt(informationRatesUponDelay[1:(stage - 1)]),
+                            contRegionLower[stage] - sqrtShift * sqrt(informationRatesUponDelay[stage]), C_UPPER_BOUNDS_DEFAULT
+                        ),
+                        nrow = 2, byrow = TRUE
                     ), informationRatesUponDelay
                 )
                 rejectionProbabilities[stage] <- probs1[2, stage + 1] - probs1[1, stage + 1] +
@@ -906,13 +927,14 @@ getGroupSequentialProbabilities <- function(decisionMatrix, informationRates) {
                 stoppingProbabilities[stage] <- probs2[2, stage] + probs1[2, stage] - probs1[1, stage]
             } else {
                 probs <- .getGroupSequentialProbabilities(
-                    matrix(c(
-                        contRegionLower[1:(stage - 1)] - sqrtShift * sqrt(informationRates[1:(stage - 1)]),
-                        decisionCriticalValues[stage] - sqrtShift * sqrt(informationRates[stage]),
-                        contRegionUpper[1:(stage - 1)] - sqrtShift * sqrt(informationRates[1:(stage - 1)]),
-                        C_UPPER_BOUNDS_DEFAULT
-                    ),
-                    nrow = 2, byrow = TRUE
+                    matrix(
+                        c(
+                            contRegionLower[1:(stage - 1)] - sqrtShift * sqrt(informationRates[1:(stage - 1)]),
+                            decisionCriticalValues[stage] - sqrtShift * sqrt(informationRates[stage]),
+                            contRegionUpper[1:(stage - 1)] - sqrtShift * sqrt(informationRates[1:(stage - 1)]),
+                            C_UPPER_BOUNDS_DEFAULT
+                        ),
+                        nrow = 2, byrow = TRUE
                     ), informationRates
                 )
                 rejectionProbabilities[stage] <- probs[2, stage] - probs[1, stage]
@@ -921,22 +943,24 @@ getGroupSequentialProbabilities <- function(decisionMatrix, informationRates) {
         } else {
             if (stage == 1) {
                 probs <- .getGroupSequentialProbabilities(
-                    matrix(c(
-                        contRegionLower[stage] - sqrtShift * sqrt(informationRates[stage]),
-                        contRegionUpper[stage] - sqrtShift * sqrt(informationRates[stage])
-                    ),
-                    nrow = 2, byrow = TRUE
+                    matrix(
+                        c(
+                            contRegionLower[stage] - sqrtShift * sqrt(informationRates[stage]),
+                            contRegionUpper[stage] - sqrtShift * sqrt(informationRates[stage])
+                        ),
+                        nrow = 2, byrow = TRUE
                     ), informationRates[1]
                 )
             } else {
                 probs <- .getGroupSequentialProbabilities(
-                    matrix(c(
-                        contRegionLower[1:(stage - 1)] - sqrtShift * sqrt(informationRates[1:(stage - 1)]),
-                        contRegionLower[stage] - sqrtShift * sqrt(informationRates[stage]),
-                        contRegionUpper[1:(stage - 1)] - sqrtShift * sqrt(informationRates[1:(stage - 1)]),
-                        contRegionUpper[stage] - sqrtShift * sqrt(informationRates[stage])
-                    ),
-                    nrow = 2, byrow = TRUE
+                    matrix(
+                        c(
+                            contRegionLower[1:(stage - 1)] - sqrtShift * sqrt(informationRates[1:(stage - 1)]),
+                            contRegionLower[stage] - sqrtShift * sqrt(informationRates[stage]),
+                            contRegionUpper[1:(stage - 1)] - sqrtShift * sqrt(informationRates[1:(stage - 1)]),
+                            contRegionUpper[stage] - sqrtShift * sqrt(informationRates[stage])
+                        ),
+                        nrow = 2, byrow = TRUE
                     ), informationRates[1:stage]
                 )
             }
@@ -1002,13 +1026,7 @@ getDesignInverseNormal <- function(...,
         twoSidedPower = NA,
         tolerance = 1e-08 # C_DESIGN_TOLERANCE_DEFAULT
         ) {
-    .warnInCaseOfUnknownArguments(functionName = "getDesignInverseNormal", ignore = c("cppEnabled"), ...)
-
-    cppEnabled <- .getOptionalArgument("cppEnabled", ..., optionalArgumentDefaultValue = TRUE)
-    if (!cppEnabled) {
-        stop("The cppEnabled option of  getDesignInverseNormal() is deprecated and no longer available in rpact")
-    }
-
+    .warnInCaseOfUnknownArguments(functionName = "getDesignInverseNormal", ...)
     return(.getDesignGroupSequential(
         designClass = C_CLASS_NAME_TRIAL_DESIGN_INVERSE_NORMAL,
         kMax = kMax,
@@ -1258,7 +1276,6 @@ getDesignInverseNormal <- function(...,
     if (design$kMax == 1) {
         .getDesignGroupSequentialKMax1(design)
     } else {
-
         # Wang and Tsiatis design
         if (design$typeOfDesign == C_TYPE_OF_DESIGN_WT ||
                 design$typeOfDesign == C_TYPE_OF_DESIGN_P ||
@@ -1340,14 +1357,6 @@ getDesignInverseNormal <- function(...,
         design$.setParameterType("stages", C_PARAM_NOT_APPLICABLE)
     }
 
-    if (design$sided == 2 && design$typeOfDesign != C_TYPE_OF_DESIGN_PT &&
-            .isBetaSpendingDesignType(design$typeBetaSpending)) {
-        warning("The two-sided beta-spending approach is experimental and ",
-            "hence not fully validated (see www.rpact.com/experimental)",
-            call. = FALSE
-        )
-    }
-
     .assertIsNumericVector(delayedInformation, "delayedInformation", naAllowed = TRUE)
     if (all(is.na(delayedInformation))) {
         # delayed response design is disabled
@@ -1433,51 +1442,56 @@ getDesignInverseNormal <- function(...,
                         ), informationRatesUponDelay
                     )
                     probs2 <- .getGroupSequentialProbabilities(
-                        matrix(c(
-                            -C_UPPER_BOUNDS_DEFAULT, secondCriticalValue,
-                            contRegionLower[stage], C_UPPER_BOUNDS_DEFAULT
-                        ),
-                        nrow = 2, byrow = TRUE
+                        matrix(
+                            c(
+                                -C_UPPER_BOUNDS_DEFAULT, secondCriticalValue,
+                                contRegionLower[stage], C_UPPER_BOUNDS_DEFAULT
+                            ),
+                            nrow = 2, byrow = TRUE
                         ), informationRatesUponDelay
                     )
                     return(probs1[1, stage + 1] - probs2[2, stage + 1] + probs2[1, stage + 1])
                 }, lower = -C_UPPER_BOUNDS_DEFAULT, upper = C_UPPER_BOUNDS_DEFAULT, tolerance = design$tolerance)
 
                 probs <- .getGroupSequentialProbabilities(
-                    matrix(c(
-                        contRegionUpper[stage], decisionCriticalValues[stage],
-                        C_UPPER_BOUNDS_DEFAULT, C_UPPER_BOUNDS_DEFAULT
-                    ),
-                    nrow = 2, byrow = TRUE
+                    matrix(
+                        c(
+                            contRegionUpper[stage], decisionCriticalValues[stage],
+                            C_UPPER_BOUNDS_DEFAULT, C_UPPER_BOUNDS_DEFAULT
+                        ),
+                        nrow = 2, byrow = TRUE
                     ), informationRatesUponDelay
                 )
             } else {
                 decisionCriticalValues[stage] <- .getOneDimensionalRoot(function(secondCriticalValue) {
                     probs1 <- .getGroupSequentialProbabilities(
-                        matrix(c(
-                            contRegionLower[1:(stage - 1)], contRegionUpper[stage], secondCriticalValue,
-                            contRegionUpper[1:(stage - 1)], C_UPPER_BOUNDS_DEFAULT, C_UPPER_BOUNDS_DEFAULT
-                        ),
-                        nrow = 2, byrow = TRUE
+                        matrix(
+                            c(
+                                contRegionLower[1:(stage - 1)], contRegionUpper[stage], secondCriticalValue,
+                                contRegionUpper[1:(stage - 1)], C_UPPER_BOUNDS_DEFAULT, C_UPPER_BOUNDS_DEFAULT
+                            ),
+                            nrow = 2, byrow = TRUE
                         ), informationRatesUponDelay
                     )
                     probs2 <- .getGroupSequentialProbabilities(
-                        matrix(c(
-                            contRegionLower[1:(stage - 1)], -C_UPPER_BOUNDS_DEFAULT, secondCriticalValue,
-                            contRegionUpper[1:(stage - 1)], contRegionLower[stage], C_UPPER_BOUNDS_DEFAULT
-                        ),
-                        nrow = 2, byrow = TRUE
+                        matrix(
+                            c(
+                                contRegionLower[1:(stage - 1)], -C_UPPER_BOUNDS_DEFAULT, secondCriticalValue,
+                                contRegionUpper[1:(stage - 1)], contRegionLower[stage], C_UPPER_BOUNDS_DEFAULT
+                            ),
+                            nrow = 2, byrow = TRUE
                         ), informationRatesUponDelay
                     )
                     return(probs1[1, stage + 1] - probs2[2, stage + 1] + probs2[1, stage + 1])
                 }, lower = -C_UPPER_BOUNDS_DEFAULT, upper = C_UPPER_BOUNDS_DEFAULT, tolerance = design$tolerance)
 
                 probs <- .getGroupSequentialProbabilities(
-                    matrix(c(
-                        contRegionLower[1:(stage - 1)], contRegionUpper[stage], decisionCriticalValues[stage],
-                        contRegionUpper[1:(stage - 1)], C_UPPER_BOUNDS_DEFAULT, C_UPPER_BOUNDS_DEFAULT
-                    ),
-                    nrow = 2, byrow = TRUE
+                    matrix(
+                        c(
+                            contRegionLower[1:(stage - 1)], contRegionUpper[stage], decisionCriticalValues[stage],
+                            contRegionUpper[1:(stage - 1)], C_UPPER_BOUNDS_DEFAULT, C_UPPER_BOUNDS_DEFAULT
+                        ),
+                        nrow = 2, byrow = TRUE
                     ), informationRatesUponDelay
                 )
             }
@@ -1634,13 +1648,7 @@ getDesignGroupSequential <- function(...,
         delayedInformation = NA_real_,
         tolerance = 1e-08 # C_DESIGN_TOLERANCE_DEFAULT
         ) {
-    .warnInCaseOfUnknownArguments(functionName = "getDesignGroupSequential", ignore = c("cppEnabled"), ...)
-
-    cppEnabled <- .getOptionalArgument("cppEnabled", ..., optionalArgumentDefaultValue = TRUE)
-    if (!cppEnabled) {
-        stop("The cppEnabled option of  getDesignGroupSequential() is deprecated and no longer available in rpact")
-    }
-
+    .warnInCaseOfUnknownArguments(functionName = "getDesignGroupSequential", ...)
     return(.getDesignGroupSequential(
         designClass = C_CLASS_NAME_TRIAL_DESIGN_GROUP_SEQUENTIAL,
         kMax = kMax,
@@ -1699,6 +1707,7 @@ getDesignGroupSequential <- function(...,
 #' Calculates the characteristics of a design and returns it.
 #'
 #' @inheritParams param_design
+#' @inheritParams param_three_dots
 #'
 #' @details
 #' Calculates the inflation factor (IF),
@@ -1709,12 +1718,12 @@ getDesignGroupSequential <- function(...,
 #' @return Returns a \code{\link{TrialDesignCharacteristics}} object.
 #' The following generics (R generic functions) are available for this result object:
 #' \itemize{
-#'   \item \code{\link[=names.FieldSet]{names}} to obtain the field names,
-#'   \item \code{\link[=print.FieldSet]{print}} to print the object,
-#'   \item \code{\link[=summary.ParameterSet]{summary}} to display a summary of the object,
-#'   \item \code{\link[=plot.ParameterSet]{plot}} to plot the object,
-#'   \item \code{\link[=as.data.frame.TrialDesignCharacteristics]{as.data.frame}} to coerce the object to a \code{\link[base]{data.frame}},
-#'   \item \code{\link[=as.matrix.FieldSet]{as.matrix}} to coerce the object to a \code{\link[base]{matrix}}.
+#'   \item \code{\link[=names.FieldSet]{names()}} to obtain the field names,
+#'   \item \code{\link[=print.FieldSet]{print()}} to print the object,
+#'   \item \code{\link[=summary.ParameterSet]{summary()}} to display a summary of the object,
+#'   \item \code{\link[=plot.ParameterSet]{plot()}} to plot the object,
+#'   \item \code{\link[=as.data.frame.TrialDesignCharacteristics]{as.data.frame()}} to coerce the object to a \code{\link[base]{data.frame}},
+#'   \item \code{\link[=as.matrix.FieldSet]{as.matrix()}} to coerce the object to a \code{\link[base]{matrix}}.
 #' }
 #' @template how_to_get_help_for_generics
 #'
@@ -1724,7 +1733,19 @@ getDesignGroupSequential <- function(...,
 #'
 #' @export
 #'
-getDesignCharacteristics <- function(design) {
+getDesignCharacteristics <- function(design = NULL, ...) {
+    if (is.null(design)) {
+        design <- .getDefaultDesign(..., type = "characteristics")
+        .warnInCaseOfUnknownArguments(
+            functionName = "getDesignCharacteristics",
+            ignore = .getDesignArgumentsToIgnoreAtUnknownArgumentCheck(design, powerCalculationEnabled = FALSE), ...
+        )
+    } else {
+        .assertIsTrialDesign(design)
+        .warnInCaseOfUnknownArguments(functionName = "getDesignCharacteristics", ...)
+        .warnInCaseOfTwoSidedPowerArgument(...)
+    }
+
     return(.getDesignCharacteristics(design = design, userFunctionCallEnabled = TRUE))
 }
 
@@ -1741,7 +1762,7 @@ getDesignCharacteristics <- function(design) {
 
     if ((design$typeOfDesign == C_TYPE_OF_DESIGN_PT ||
             .isBetaSpendingDesignType(design$typeBetaSpending)) && design$sided == 2 && design$kMax == 2) {
-        design$futilityBounds[is.na(design$futilityBounds)] <- 0 ##  otherwise .getValidatedFutilityBounds returns -6 !
+        design$futilityBounds[is.na(design$futilityBounds)] <- 0
     }
 
     design$futilityBounds <- .getValidatedFutilityBounds(design,
@@ -1847,7 +1868,8 @@ getDesignCharacteristics <- function(design) {
 
         designCharacteristics$rejectionProbabilities <- rejectionProbabilities
         designCharacteristics$futilityProbabilities <- futilityProbabilities
-    } else if ((design$typeOfDesign == C_TYPE_OF_DESIGN_PT || .isBetaSpendingDesignType(design$typeBetaSpending)) && design$sided == 2) {
+    } else if ((design$typeOfDesign == C_TYPE_OF_DESIGN_PT || 
+            .isBetaSpendingDesignType(design$typeBetaSpending)) && design$sided == 2) {
         design$futilityBounds[is.na(design$futilityBounds)] <- 0
 
         shift <- .getOneDimensionalRoot(
@@ -2074,13 +2096,13 @@ getDesignCharacteristics <- function(design) {
 #' @return Returns a \code{\link{PowerAndAverageSampleNumberResult}} object.
 #' The following generics (R generic functions) are available for this result object:
 #' \itemize{
-#'   \item \code{\link[=names.FieldSet]{names}} to obtain the field names,
-#'   \item \code{\link[=print.FieldSet]{print}} to print the object,
-#'   \item \code{\link[=summary.ParameterSet]{summary}} to display a summary of the object,
-#'   \item \code{\link[=plot.ParameterSet]{plot}} to plot the object,
-#'   \item \code{\link[=as.data.frame.PowerAndAverageSampleNumberResult]{as.data.frame}}
+#'   \item \code{\link[=names.FieldSet]{names()}} to obtain the field names,
+#'   \item \code{\link[=print.FieldSet]{print()}} to print the object,
+#'   \item \code{\link[=summary.ParameterSet]{summary()}} to display a summary of the object,
+#'   \item \code{\link[=plot.ParameterSet]{plot()}} to plot the object,
+#'   \item \code{\link[=as.data.frame.PowerAndAverageSampleNumberResult]{as.data.frame()}}
 #'         to coerce the object to a \code{\link[base]{data.frame}},
-#'   \item \code{\link[=as.matrix.FieldSet]{as.matrix}} to coerce the object to a \code{\link[base]{matrix}}.
+#'   \item \code{\link[=as.matrix.FieldSet]{as.matrix()}} to coerce the object to a \code{\link[base]{matrix}}.
 #' }
 #' @template how_to_get_help_for_generics
 #'
@@ -2136,13 +2158,25 @@ getPowerAndAverageSampleNumber <- function(design, theta = seq(-1, 1, 0.02), nMa
     ))
 }
 
+
 #'
+#' @title 
+#' Simulated Rejections Delayed Response
+#' 
+#' @description 
 #' Simulates the rejection probability of a delayed response group sequential design with specified parameters.
+#' 
+#' @inheritParams param_design
+#' @param delta The delay value.
+#' @param iterations The number of simulation iterations.
+#' @inheritParams param_seed
+#' 
+#' @details 
 #' By default, delta = 0, i.e., the Type error rate is simulated.
 #'
-#' @keywords internal
+#' @return Returns a list summarizing the rejection probabilities.
 #'
-#' @export
+#' @noRd
 #'
 getSimulatedRejectionsDelayedResponse <- function(design, ..., delta = 0, iterations = 10000, seed = NA_real_) {
     .assertIsTrialDesignInverseNormalOrGroupSequential(design)
