@@ -13,8 +13,8 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 6285 $
-## |  Last changed: $Date: 2022-06-10 10:49:23 +0200 (Fri, 10 Jun 2022) $
+## |  File version: $Revision: 7645 $
+## |  Last changed: $Date: 2024-02-16 16:12:34 +0100 (Fr, 16 Feb 2024) $
 ## |  Last changed by: $Author: pahlke $
 ## |
 
@@ -62,7 +62,7 @@ NULL
         selectedVector[4] <- selectedPopulations[1, stage] || selectedPopulations[2, stage] || selectedPopulations[4, stage]
         selectedVector[5] <- selectedPopulations[1, stage] || selectedPopulations[3, stage] || selectedPopulations[4, stage]
         selectedVector[6] <- selectedPopulations[2, stage] || selectedPopulations[3, stage] || selectedPopulations[4, stage]
-        selectedVector[7] <- selectedPopulations[1, stage] || selectedPopulations[2, stage] || selectedPopulations[3, stage] || 
+        selectedVector[7] <- selectedPopulations[1, stage] || selectedPopulations[2, stage] || selectedPopulations[3, stage] ||
             selectedPopulations[4, stage]
         selectedVector[8] <- selectedPopulations[4, stage]
     }
@@ -159,7 +159,7 @@ NULL
     separatePValues <- stageResults$separatePValues
     if (intersectionTest == "SpiessensDebois") {
         subjectsPerStage <- stageResults[[ifelse(
-            !is.null(stageResults[["subjectsPerStage"]]), "subjectsPerStage", "eventsPerStage"
+            !is.null(stageResults[["subjectsPerStage"]]), "subjectsPerStage", "cumulativeEventsPerStage"
         )]]
         testStatistics <- stageResults$testStatistics
     } else {
@@ -256,7 +256,7 @@ NULL
 
         if (k < kMax) {
             futilityStop[k] <- all(futility[stageResults$selectedPopulations[1:gMax, k], k])
-            if (all(stageResults$selectedPopulations[1:gMax, k + 1] == FALSE)) {
+            if (all(!stageResults$selectedPopulations[1:gMax, k + 1], na.rm = TRUE)) {
                 futilityStop[k] <- TRUE
             }
         }
@@ -276,7 +276,6 @@ NULL
 
 .createSimulationResultsEnrichmentObject <- function(...,
         design,
-        populations,
         effectList,
         intersectionTest,
         stratifiedAnalysis = NA,
@@ -315,7 +314,7 @@ NULL
 
     .assertIsSinglePositiveInteger(rValue, "rValue", naAllowed = TRUE, validateType = FALSE)
 
-    .assertIsSingleNumber(allocationRatioPlanned, "allocationRatioPlanned", naAllowed = TRUE)
+    .assertIsNumericVector(allocationRatioPlanned, "allocationRatioPlanned", naAllowed = TRUE)
     .assertIsInOpenInterval(allocationRatioPlanned, "allocationRatioPlanned", 0, C_ALLOCATION_RATIO_MAXIMUM, naAllowed = TRUE)
 
     .assertIsSingleNumber(conditionalPower, "conditionalPower", naAllowed = TRUE)
@@ -359,20 +358,13 @@ NULL
         simulationResults <- SimulationResultsEnrichmentSurvival(design, showStatistics = showStatistics)
     }
 
-    .assertIsSinglePositiveInteger(populations, "populations", naAllowed = TRUE, validateType = FALSE)
-    if (is.na(populations)) {
-        if (is.null(effectList) || is.null(effectList[["subGroups"]])) {
-            .assertIsSinglePositiveInteger(populations, "populations", naAllowed = FALSE, validateType = FALSE)
-        }
-        populations <- .getGMaxFromSubGroups(effectList$subGroups)
+    effectList <- .getValidatedEffectList(effectList, endpoint = endpoint)
+    gMax <- .getGMaxFromSubGroups(effectList$subGroups)
+    if (gMax > 4) {
+        stop(C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, "'populations' (", gMax, ") must not exceed 4")
     }
 
-    if (populations > 4) {
-        stop(C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, "'populations' (", populations, ") max not exceed 4")
-    }
-
-    gMax <- populations
-    kMax <- design$kMax
+    .assertIsValidThreshold(threshold, activeArms = gMax)
 
     intersectionTest <- intersectionTest[1]
     .assertIsValidIntersectionTestEnrichment(design, intersectionTest)
@@ -385,7 +377,7 @@ NULL
         )
     }
 
-    typeOfSelection <- .assertIsValidTypeOfSelection(typeOfSelection, rValue, epsilonValue, populations)
+    typeOfSelection <- .assertIsValidTypeOfSelection(typeOfSelection, rValue, epsilonValue, gMax)
     if (length(typeOfSelection) == 1 && typeOfSelection == "userDefined" &&
             !is.null(threshold) && length(threshold) == 1 && threshold != -Inf) {
         warning("'threshold' (", threshold, ") will be ignored because 'typeOfSelection' = \"userDefined\"", call. = FALSE)
@@ -401,16 +393,16 @@ NULL
     if (endpoint %in% c("rates", "survival")) {
         .setValueAndParameterType(simulationResults, "directionUpper", directionUpper, TRUE)
     }
-    
+
     if (!stratifiedAnalysis && endpoint %in% c("means", "survival")) {
         stop(
             C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT,
-            "For testing ", endpoint, ifelse(endpoint == "survival", " designs", ""), 
+            "For testing ", endpoint, ifelse(endpoint == "survival", " designs", ""),
             ", only stratified analysis is supported"
         )
     }
 
-    effectList <- .getValidatedEffectList(effectList, gMax = gMax)
+    kMax <- design$kMax
     if (endpoint == "means") {
         stDevH1 <- .ignoreParameterIfNotUsed(
             "stDevH1", stDevH1, kMax > 1,
@@ -446,8 +438,6 @@ NULL
         .setValueAndParameterType(simulationResults, "plannedEvents", plannedEvents, NA_real_)
     }
 
-    .assertIsValidThreshold(threshold, gMax)
-
     if (endpoint %in% c("means", "rates")) {
         .assertIsValidPlannedSubjects(plannedSubjects, kMax) # means + rates only
     }
@@ -459,24 +449,6 @@ NULL
         )
     }
 
-    if (endpoint == "means") {
-# 		if (is.na(conditionalPower) && is.null(calcSubjectsFunction) && !is.na(thetaH1)) {
-# 			warning("'thetaH1' will be ignored because neither 'conditionalPower' nor ",
-# 				"'calcSubjectsFunction' is defined", call. = FALSE)
-# 		}
-# 		if (is.na(conditionalPower) && is.null(calcSubjectsFunction) && !is.na(stDevH1)) {
-# 			warning("'stDevH1' will be ignored because neither 'conditionalPower' nor ",
-# 				"'calcSubjectsFunction' is defined", call. = FALSE)
-# 		}
-    }
-
-    if (endpoint == "survival") {
-# 		if (is.na(conditionalPower) && is.null(calcEventsFunction) && !is.na(thetaH1)) {
-# 			warning("'thetaH1' will be ignored because neither 'conditionalPower' nor ",
-# 				"'calcEventsFunction' is defined", call. = FALSE)
-# 		}
-    }
-
     conditionalPower <- .ignoreParameterIfNotUsed(
         "conditionalPower",
         conditionalPower, kMax > 1, "design is fixed ('kMax' = 1)"
@@ -660,13 +632,33 @@ NULL
         simulationResults$calcEventsFunction <- calcEventsFunction
     }
 
-    if (is.na(allocationRatioPlanned)) {
+    if (any(is.na(allocationRatioPlanned))) {
         allocationRatioPlanned <- C_ALLOCATION_RATIO_DEFAULT
     }
-    .setValueAndParameterType(
-        simulationResults, "allocationRatioPlanned",
-        allocationRatioPlanned, C_ALLOCATION_RATIO_DEFAULT
-    )
+
+    if (length(allocationRatioPlanned) == 1) {
+        allocationRatioPlanned <- rep(allocationRatioPlanned, design$kMax)
+    } else if (length(allocationRatioPlanned) != design$kMax) {
+        stop(
+            C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT,
+            "'allocationRatioPlanned' (", .arrayToString(allocationRatioPlanned), ") ",
+            "must have length 1 or ", design$kMax, " (kMax)"
+        )
+    }
+
+    if (length(unique(allocationRatioPlanned)) == 1) {
+        .setValueAndParameterType(
+            simulationResults, "allocationRatioPlanned",
+            allocationRatioPlanned[1],
+            defaultValue = 1
+        )
+    } else {
+        .setValueAndParameterType(
+            simulationResults, "allocationRatioPlanned",
+            allocationRatioPlanned,
+            defaultValue = rep(1, design$kMax)
+        )
+    }
 
     if (endpoint %in% c("means", "rates")) {
         .setValueAndParameterType(simulationResults, "plannedSubjects", plannedSubjects, NA_real_)
@@ -714,17 +706,17 @@ NULL
     }
     .setValueAndParameterType(simulationResults, "adaptations", adaptations, rep(TRUE, kMax - 1))
 
+    simulationResults$effectList <- effectList
     simulationResults$.setParameterType("effectList", C_PARAM_USER_DEFINED)
 
-    simulationResults$effectList <- effectList
+    simulationResults$populations <- as.integer(gMax)
+    simulationResults$.setParameterType("populations", C_PARAM_DERIVED)
 
     .setValueAndParameterType(
         simulationResults, "stratifiedAnalysis", stratifiedAnalysis,
         C_STRATIFIED_ANALYSIS_DEFAULT
     )
 
-    .setValueAndParameterType(simulationResults, "populations", as.integer(populations), C_POPULATIONS_DEFAULT)
-
     if (typeOfSelection != "userDefined") {
         .setValueAndParameterType(simulationResults, "threshold", threshold, -Inf)
         .setValueAndParameterType(simulationResults, "epsilonValue", epsilonValue, NA_real_)
@@ -736,6 +728,6 @@ NULL
     .setValueAndParameterType(simulationResults, "effectMeasure", effectMeasure, C_EFFECT_MEASURE_DEFAULT)
 
     warning("Simulation of enrichment designs is experimental and hence not fully validated (see www.rpact.com/experimental)", call. = FALSE)
-    
+
     return(simulationResults)
 }
