@@ -14,8 +14,8 @@
  *
  * Contact us for information about our services: info@rpact.com
  *
- * File version: $Revision: 6417 $
- * Last changed: $Date: 2022-07-15 09:24:52 +0200 (Fri, 15 Jul 2022) $
+ * File version: $Revision: 7408 $
+ * Last changed: $Date: 2023-11-09 10:36:19 +0100 (Do, 09 Nov 2023) $
  * Last changed by: $Author: pahlke $
  *
  */
@@ -24,7 +24,6 @@
 
 // [[Rcpp::plugins(cpp11)]]
 
-#include <cmath>
 #include "f_utilities.h"
 #include "rpact_types.h"
 
@@ -379,7 +378,7 @@ Rcpp::XPtr<calcSubjectsFunctionMeansPtr> getSimulationMeansStageSubjectsXPtr() {
   return Rcpp::XPtr<calcSubjectsFunctionMeansPtr>(new calcSubjectsFunctionMeansPtr(&getSimulationMeansStageSubjects));
 }
 
-// [[Rcpp::export]]
+// [[Rcpp::export(name = ".getSimulationMeansLoopCpp")]]
 List getSimulationMeansLoopCpp(
 		NumericVector alternative,
 		int kMax,
