@@ -1,6 +1,6 @@
 /**
  *
- * -- Simulation of means with group sequential and combination test --
+ * -- Simulation of rates with group sequential and combination test --
  *
  * This file is part of the R package rpact:
  * Confirmatory Adaptive Clinical Trial Design and Analysis
@@ -14,8 +14,8 @@
  *
  * Contact us for information about our services: info@rpact.com
  *
- * File version: $Revision: 6417 $
- * Last changed: $Date: 2022-07-15 09:24:52 +0200 (Fri, 15 Jul 2022) $
+ * File version: $Revision: 7461 $
+ * Last changed: $Date: 2023-12-01 10:24:25 +0100 (Fr, 01 Dez 2023) $
  * Last changed by: $Author: pahlke $
  *
  */
@@ -24,7 +24,6 @@
 
 // [[Rcpp::plugins(cpp11)]]
 
-#include <cmath>
 #include "f_assertions.h"
 #include "f_utilities.h"
 #include "rpact_types.h"
@@ -632,7 +631,7 @@ List getSimulationStepRatesCpp(int k, int kMax, int designNumber, NumericVector
 	);
 }
 
-// [[Rcpp::export]]
+// [[Rcpp::export(name = ".getSimulationRatesCpp")]]
 List getSimulationRatesCpp(
 		int kMax,
 		NumericVector informationRates,
@@ -825,10 +824,6 @@ List getSimulationRatesCpp(
 		}
 	}
 
-	sapply(sampleSizes, [](double x) {
-		return NumericVector::is_na(x) ? 0 : x;
-	});
-
 	for (int m = 0; m < sampleSizes.length(); m++) {
 		if (NumericVector::is_na((double) sampleSizes[m])) {
 			sampleSizes[m] = 0;
